@@ -29,6 +29,28 @@ def cli(token=None):
     client = create_client_from_env()
 
 
+@cli.group()
+def event():
+    pass
+
+
+@event.command()
+@click.option("-t", "--title", required=True)
+@click.option("-c", "--content", required=True)
+def create(title, content):
+    client.event.create(title, content)
+
+
+@cli.group()
+def instance():
+    pass
+
+
+@instance.command()
+def release():
+    client.instance.release()
+
+
 @cli.group()
 def port():
     pass
@@ -78,8 +100,10 @@ def upload(file, name, range, description, proxy):
     if not proxy:
         os.environ['HTTP_PROXY'] = ''
         os.environ['HTTPS_PROXY'] = ''
-        os.environ['http_proxy'] = ''
+        os.environ['ALL_PROXY'] = ''
         os.environ['https_proxy'] = ''
+        os.environ['http_proxy'] = ''
+        os.environ['all_proxy'] = ''
     if not (file.endswith(".zip") or file.endswith(".tar.gz")):
         sys.exit('Error: uploading file should be one of .zip or .tar.gz type')
     filepath = Path(file)
@@ -110,7 +134,7 @@ def upload(file, name, range, description, proxy):
         credential['AccessKeySecret'],
         credential['SecurityToken']
     )
-    bucket = oss2.Bucket(auth, 'http://oss-cn-beijing.aliyuncs.com', dataset['dataset_center']['bucket'])
+    bucket = oss2.Bucket(auth, 'http://oss-cn-chengdu.aliyuncs.com', dataset['dataset_center']['bucket'])
 
     def progress_callback(consumed_bytes, total_bytes):
         pbar.update(consumed_bytes - pbar.n)
@@ -136,7 +160,7 @@ def upload(file, name, range, description, proxy):
     client.dataset.update(
         dataset_id=dataset['id'],
         uploaded=True,
-        domain=f"{dataset['dataset_center']['bucket']}.oss-cn-beijing.aliyuncs.com",
+        domain=f"{dataset['dataset_center']['bucket']}.oss-cn-chengdu.aliyuncs.com",
         path=path,
         size=total_size,
         filename=filepath.name
