@@ -1,4 +1,4 @@
-from .resource import Instance, Dataset, OssCredentials, Notebook, Port
+from .resource import Instance, Dataset, OssCredentials, Notebook, Port, Event
 
 
 class FeaturizeClient:
@@ -11,6 +11,10 @@ class FeaturizeClient:
     def instance(self) -> Instance:
         return self._get_resource(Instance)
 
+    @property
+    def event(self) -> Event:
+        return self._get_resource(Event)
+
     @property
     def port(self) -> Port:
         return self._get_resource(Port)
@@ -28,7 +32,7 @@ class FeaturizeClient:
         return self._get_resource(Notebook)
 
     def _get_resource(self, resource_type):
-        resource_name = resource_type.__class__.__name__
+        resource_name = resource_type.__name__
         if not hasattr(self, resource_name):
             setattr(self, resource_name, resource_type(self.token, self.instance_id))
         return getattr(self, resource_name)
